docx\_parser\_converter.docx\_parsers.tables package
====================================================

Submodules
----------

.. toctree::
   :maxdepth: 4

   docx_parser_converter.docx_parsers.tables.table_cell_parser
   docx_parser_converter.docx_parsers.tables.table_cell_properties_parser
   docx_parser_converter.docx_parsers.tables.table_grid_parser
   docx_parser_converter.docx_parsers.tables.table_properties_parser
   docx_parser_converter.docx_parsers.tables.table_row_parser
   docx_parser_converter.docx_parsers.tables.table_row_properties_parser
   docx_parser_converter.docx_parsers.tables.tables_parser

Module contents
---------------

.. automodule:: docx_parser_converter.docx_parsers.tables
   :members:
   :undoc-members:
   :show-inheritance:
